@@ -1,15 +1,15 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-02-06 16:27:40 mtw>
+# Last changed Time-stamp: <2017-06-10 18:18:45 michl>
 
 package Bio::ViennaNGS::AnnoC;
-
-use version; our $VERSION = qv('0.12_15');
+use Bio::ViennaNGS;
 use Bio::ViennaNGS::Util qw(sortbed);
 use Bio::Tools::GFF;
 use Path::Class;
 use Carp;
 use Moose;
 use namespace::autoclean;
+use version; our $VERSION = version->declare(eval($Bio::ViennaNGS::VERSION));
 
 has 'accession' => (
 		    is => 'rw',
@@ -276,11 +276,16 @@ scenarios, including spliced isoforms.
 =item parse_gff
 
 Title : parse_gff
-Usage : C<<$obj->parse_gff($gff3_file);>>
+
+Usage : C<$obj-E<gt>parse_gff($gff3_file);>
+
 Function: Parses GFF3 annotation files of non-spliced genomes into
-          C<<$self->features>>
+          C<$self-E<gt>features>
+
 Args : The full path to a GFF3 file
+
 Returns :
+
 Notes : The GFF3 specification is available at
         L<http://www.sequenceontology.org/resources/gff3.html>. This
         routine has been tested with NCBI bacteria GFF3 annotation.
@@ -288,26 +293,34 @@ Notes : The GFF3 specification is available at
 =item feature_summary
 
 Title : feature_summary
-Usage : C<<$obj->feature_summary($dest);>>
+
+Usage : C<$obj-E<gt>feature_summary($dest);>
+
 Function : Generate a summary file for all features present in
-           C<<$self->features>>
+           C<$self-E<gt>features>
+
 Args : Full output path for summary.txt file
+
 Returns :
 
 =item features2bed
 
 Title : features2bed
-Usage : C<<$obj->features2bed($feature,$workdir,$bn,$log);>>
-Function : Dumps genomic features from C<$self->features> hash to a
+
+Usage : C<$obj-E<gt>features2bed($feature,$workdir,$bn,$log);>
+
+Function : Dumps genomic features from C<$self-E<gt>features> hash to a
            BED12 file.
-Args : C<<$gbkey>> can be either a string corresponding to a genbank
-       key in C<<$self->featstat>> or C<undef>. If defined, only
+
+Args : C<$gbkey> can be either a string corresponding to a genbank
+       key in C<$self-E<gt>featstat> or C<undef>. If defined, only
        features of the speficied key will be dumped to a single BED12
        file. If C<$gbkey> is C<undef>, BED12 files will be generated
-       for each type present in C<<$self->featstat>>.  C<$dest> is the
+       for each type present in C<$self-E<gt>featstat>.  C<$dest> is the
        output directory and C<$bn> the basename for all output
        files. C<$log> is either be the full path to a logfile or
        C<undef>.
+
 Returns  :
 
 =back
@@ -332,7 +345,7 @@ Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2015 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
+Copyright (C) 2014-2017 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
