@@ -1,5 +1,5 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2017-06-10 19:04:16 michl>
+# Last changed Time-stamp: <2018-11-25 21:40:36 mtw>
 
 package Bio::ViennaNGS::FeatureInterval;
 
@@ -10,41 +10,61 @@ use Moose;
 use version; our $VERSION = version->declare("$Bio::ViennaNGS::VERSION");
 
 has 'chromosome' => (
-		     is  => 'ro',
+		     is  => 'rw',
 		     isa => 'Str',
 		     required => 1,
 		     predicate => 'has_chromosome',
-	     );
+		    );
 
 has 'start' => (
-		is      => 'ro',
+		is      => 'rw',
 		isa     => 'Int',
 		required => 1,
 		predicate => 'has_start',
 	       );
 
 has 'end' => (
-	      is      => 'ro',
+	      is      => 'rw',
 	      isa     => 'Int',
 	      required => 1,
 	      predicate => 'has_end',
 	     );
 
 has '_length' => ( # length of interval
-		   is => 'rw',
-		   isa => 'Int',
-		   predicate => 'length',
-		   init_arg => undef, # make this unsettable via constructor
+		  is => 'rw',
+		  isa => 'Int',
+		  predicate => 'length',
+		  init_arg => undef, # make this unsettable via constructor
 		 );
 
+with 'Bio::ViennaNGS::FeatureBase';
+
 sub BUILD { # call a parser method, depending on $self->instanceOf
   my $self = shift;
   my $this_function = (caller(0))[3];
+  my $len = undef;
 
-  confess "ERROR [$this_function] \$self->end must be >= than \$self->start"
-    unless ($self->end >= $self->start);
-  my $len = $self->end-$self->start;
-  $self->_length($len);
+  if ($self->base == 0){
+    confess "ERROR [$this_function] \$self->end must be > than \$self->start for 0-based start coordinates [==> start ".eval($self->start)." end ".eval($self->end)." <==]"
+      unless ($self->end > $self->start);
+    $len = eval($self->end)-eval($self->start)-1;
+    $self->_length($len);
+  }
+  else {
+    confess "ERROR [$this_function] \$self->end must be >= than \$self->start for 0-based start coordinates [==> start ".eval($self->start)." end ".eval($self->end)." <==]"
+      unless ($self->end >= $self->start);
+    $len = $self->end-$self->start;
+    $self->_length($len);
+  }
+}
+
+sub dump {
+  my $self = shift;
+  print join("\t",
+	     $self->chromosome,
+	     $self->start,
+	     $self->end),
+	       "\n";
 }
 
 no Moose;
@@ -66,8 +86,8 @@ genomic intervals.
                                                  start => "1200",
                                                  end => "4300",
                                                 );
-
   my $len = $obj->_length();
+  $obj->dump();
 
 =head1 DESCRIPTION
 
@@ -78,6 +98,21 @@ for BED3 elements.
 
 This is the base class for L<Bio::ViennaNGS::MinimalFeature>.
 
+=head1 METHODS
+
+=over
+
+=item dump()
+
+Title   : dump
+
+Usage   : C<$obj-E<gt>dump;>
+
+Function: Print a tab-separated representation of C<$obj> (a BED3
+          line).
+
+=back
+
 =head1 SEE ALSO
 
 =over
@@ -94,7 +129,7 @@ Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2017 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
+Copyright (C) 2014-2018 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
