@@ -1,11 +1,13 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-02-06 16:28:31 mtw>
+# Last changed Time-stamp: <2017-06-10 19:03:07 michl>
 
 package Bio::ViennaNGS::FeatureLine;
 
-use version; our $VERSION = qv('0.12_15');
-use namespace::autoclean;
+use Bio::ViennaNGS;
 use Moose;
+use namespace::autoclean;
+use version; our $VERSION = version->declare("$Bio::ViennaNGS::VERSION");
+
 extends 'Bio::ViennaNGS::MinimalFeature';
 
 has 'id' => (
