@@ -1,28 +1,27 @@
 # -*-CPerl-*-
-# Last changed Time-stamp: <2015-02-09 15:09:19 fall>
-
+# Last changed Time-stamp: <2017-06-10 19:12:00 michl>
 
 package Bio::ViennaNGS::Util;
 
+use Bio::ViennaNGS;
 use Exporter;
-use version; our $VERSION = qv('0.12_16');
 use strict;
 use warnings;
 use Data::Dumper;
-use File::Basename qw(fileparse);
+use File::Basename qw(fileparse basename);
 use IPC::Cmd qw(can_run run);
 use Path::Class qw(dir file);
 use File::Path qw(make_path remove_tree);
 use Math::Round;
 use Carp;
-use Bio::ViennaNGS::FeatureChain;
+use Env qw(HOME);
+use version; our $VERSION = version->declare("$Bio::ViennaNGS::VERSION");
 
 our @ISA = qw(Exporter);
 our @EXPORT = ();
 
 our @EXPORT_OK = qw ( bed_or_bam2bw sortbed bed2bigBed unique_array
-		      kmer_enrichment extend_chain parse_bed6
-		      fetch_chrom_sizes mkdircheck rmdircheck);
+		      kmer_enrichment fetch_chrom_sizes mkdircheck rmdircheck);
 
 
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
@@ -37,8 +36,7 @@ my %unique = ();
 
 sub bed_or_bam2bw {
   my ($type,$infile,$chromsizes,$strand,$dest,$want_norm,$size,$scale,$log) = @_;
-  my ($fn_bg_tmp,$fn_bg,$fn_bw);
-  my ($bn,$path,$ext,$cmd);
+  my ($fn_bg_tmp,$fn_bg,$fn_bw,$fn,$bn,$path,$ext,$cmd);
   my @processed_files = ();
   my $factor = 1.;
   my $this_function = (caller(0))[3];
@@ -73,8 +71,12 @@ sub bed_or_bam2bw {
       if(defined $log);
   }
 
-  ($bn,$path,$ext) = fileparse($infile, qr /\..*/);
-  $fn_bg_tmp  = file($dest,$bn.".tmp.bg");
+  if ($type eq "bam"){$ext = ".bam";}
+  else{$ext = ".bed";}
+  $bn = basename($infile,$ext);
+  $fn = fileparse($infile);
+
+  $fn_bg_tmp  = file($dest,$fn.".tmp.bg");
   $fn_bg      = file($dest,$bn.".bg");
   if($strand eq "+"){
     $fn_bw  = file($dest,$bn.".pos.bw");
@@ -207,7 +209,7 @@ sub unique_array{
 sub kmer_enrichment{
 
     my @seqs =  @{$_[0]};
-    my $klen     = $_[1]; 
+    my $klen     = $_[1];
 #    my @seq = split( //, $read_tmp );
     my $kstring ='';
 #return variables
@@ -226,131 +228,6 @@ sub kmer_enrichment{
     return( \%km );
 }
 
-sub extend_chain{
-  my %sizes = %{$_[0]};
-  my $chain = $_[1];
-  my $l	    = $_[2];
-  my $r	    = $_[3];
-  my $u     = $_[4];
-  my $d     = $_[5];
-  my $e     = $_[6];
-  my $this_function = (caller(0))[3];
-
-  ##return a new chain with extended coordinates
-  my $extendchain = $chain -> clone();
-  ## got through all features in original chain, calculate new start and end and safe in extendchain
-  my @featarray = @{$extendchain->chain};
-  foreach my $feature (@featarray){
-    my $chrom  = $feature->chromosome;
-    my $start  = $feature->start;
-    my $end    = $feature->end;
-    my $strand = $feature->strand;
-    my $right  = 0;
-    my $left   = 0;
-    my $width  = nearest(1,($end-$start)/2);
-    $width = 0 if ($d > 0 || $u > 0 || !$e);
-    if ($strand eq "+"){
-      if ($d > 0){
-	$start = $end;
-	$r = $d;
-      }
-      if ($u > 0){
-	$end = $start;
-	$l = $u;
-      }
-      $right=$r;
-      $left=$l;
-    }
-    elsif ($strand eq "-"){
-      if ($u > 0){
-	$start = $end;
-	$l = $u;
-      }
-      if ($d > 0){
-	$end = $start;
-	$r = $d;
-      }
-      $right=$l;
-      $left=$r;
-    }
-    if (($right-$width) <= 0){
-      $right = 0;
-    }
-    else{
-      $right-=$width;
-    }
-    if (($left-$width) <= 0 ){
-      $left = 0;
-    }
-    else{
-      $left-=$width;
-    }
-    if ( $start-$left >= 1 ){
-      if ($end+$right >= $sizes{"chr".$chrom}){
-	$end = $sizes{"chr".$chrom};
-      }
-      else{
-	$end += $right;
-      }
-      $start -= $left;
-    }
-    elsif ( $start-$left <= 0 ){
-      $start = 0;
-      if ($end+$right >= $sizes{"chr".$chrom}){
-	$end = $sizes{"chr".$chrom};
-      }
-      else{
-	$end = $end+$right;
-      }
-    }
-    else{
-      croak "ERROR [$this_function] Something wrong here!\n";
-    }
-    $feature->start($start);
-    $feature->end($end);
-  }
-  $extendchain->type('extended');
-  return($extendchain);
-}
-
-sub parse_bed6{
-  my $bedfile = shift;
-  my $this_function = (caller(0))[3];
-  open (my $Bed, "<:gzip(autopop)",$bedfile) or 
-    croak "ERROR [$this_function] $!";
-  my @featurelist; ## This will become a FeatureChain
-  while(<$Bed>){
-    ### This should be done by FeatureIO
-    chomp (my $raw = $_);
-    push my @line , split (/\t/,$raw);
-    push @line, "\." if ( !$line[5] ); 
-
-    (my $chromosome  = $line[0])=~ s/chr//g;
-    my $start	     = $line[1];
-    my $end	     = $line[2];
-    my $name	     = $line[3];
-    my $score	     = $line[4];
-    my $strand	     = $line[5];
-    my $extension = '';
-
-    if ($line[6]){
-      for (6..$#line){
-	$extension .= $line[$_]."\t";
-      }
-      $extension = substr($extension,0,-1);
-    }
-    my $feat = Bio::ViennaNGS::Feature->new(chromosome=>$chromosome,
-					    start=>$start,
-					    end=>$end,
-					    name=>$name,
-					    score=>$score,
-					    strand=>$strand,
-					    extension=>$extension);
-    push @featurelist, $feat;
-  }
-  return (\@featurelist);
-}
-
 sub fetch_chrom_sizes{
   my $species = shift;
   my %sizes;
@@ -403,13 +280,19 @@ sub mkdircheck {
   }
   foreach (@dirstocreate){
     my @total = split(/[\/\\]/,$_);
+    if ($total[0] eq '~'){
+      $total[0]=$HOME;
+      carp "WARNING [$this_function] replacing \'~\' in path with \'$HOME\'";
+    }
     my $dir;
     while(@total){
       $dir = dir(shift(@total)) unless (defined $dir);
       $dir = dir($dir,shift(@total));
     }
-    return if (-d $dir);
-    make_path($dir,{ verbose => 1 }) or croak "Error creating directory: $dir\t$, in $this_function!";
+    my $check = $dir->stringify();
+    return if (-d $check);
+    make_path($dir,{ verbose => 0 }) or
+      croak "ERROR [$this_function] Cannot create directory $check";
   }
 }
 
@@ -421,13 +304,15 @@ sub rmdircheck {
   }
   foreach (@dirstorm){
     my @total = split(/[\/\\]/,$_);
-    my $dir='';
+    my $dir;
     while(@total){
       $dir = dir(shift(@total)) unless (defined $dir);
       $dir = dir($dir,shift(@total));
     }
-    return if (!-d $dir);
-    remove_tree($dir,{ verbose => 1 }) or croak "Error deleting directory: $dir, in $this_function!";
+    my $check = $dir->stringify();
+    return if (!-d $check);
+    remove_tree($dir,{ verbose => 0 }) or
+      croak "ERROR [$this_function] Cannot remove directory $check";
   }
 }
 
@@ -529,34 +414,19 @@ The conversion from BED to bigBed is done by a third-party utility
 (bedToBigBed), which is executed by L<IPC::Cmd>.
 
 
-=item unique_array
+=item unique_array($arrayref)
 
 Takes a reference to an array and uniques entries via hash copy.
 Returns a reference to an array containing unique values.
 
-=item kmer_enrichment
+=item kmer_enrichment($seqs,$klen)
 
 Takes a reference to a sequence array and the length of the desired
-kmer.  Counts occurences of kmers of given length and returns a
+kmer. Counts occurences of kmers of given length and returns a
 reference to a hash containing the kmer as key and occurences as
 value.
 
-=item extend_chain
-
-Takes a hash containing chromosomes and their corresponding sizes, as
-e.g. returned by the L<fetch_chrom_sizes> method. Second argument is a
-chain as generated by L<parse_bed6>.
-
-This chain is then either extended to the desired minimal size, extend
-from either the 5' and/or 3' end of the chain or returns only the 5'
-or 3' extended region plus an optional extension into the existing
-chain.
-
-=item parse_bed6
-
-Takes a path to a bed6 file optionally containing additional fields and returns a reference to an array of L<ViennaNGS::Feature> objects. This array can then easily be used for creation of an L<ViennaNGS::FeatureChain> object.
-
-=item fetch_chrom_sizes
+=item fetch_chrom_sizes($species)
 
 Takes the name of the desired species (e.g. hg19, mm9, ..) and
 retrieves annotated chromosomes and their sizes from UCSC. This
@@ -565,12 +435,12 @@ and their corresponding size as value. Either uses the fetchChromSizes
 util of the UCSC bin collection or alternatively and if mysql is
 available via a mysql command.
 
-=item mkdircheck
+=item mkdircheck(@dirs)
 
 Takes the path to one or more directories, converts them to an OS
 specific path and creates directories.
 
-=item rmdircheck
+=item rmdircheck(@dirs)
 
 Takes the path to one or more directories, converts them to an OS
 specific path and removes directories.
@@ -581,8 +451,6 @@ specific path and removes directories.
 
 =over
 
-=item L<Bio::ViennaNGS::FeatureChain>
-
 =item L<Bio::Perl> >= 1.00690001
 
 =item L<File::Basename>
@@ -622,7 +490,7 @@ Examples for using most of the provided methods can be found at L<ViennaNGS::Tut
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
+Copyright (C) 2015-2017 Michael T. Wolfinger E<lt>michael@wolfinger.euE<gt>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.0 or,
