@@ -47,18 +47,17 @@ my $genome_identifier = '-';
 my $folder_in = '-';
 my $dest = '.';
 my $base_URL = '-';
-my $chrom_size_file = '-';
+my $big_bed_urls = '-';
 my $big_wig_urls = '-';
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
 #^^^^^^^^^^^^^^ Main ^^^^^^^^^^^^^#
 #^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^#
 Getopt::Long::config('no_ignore_case');
 pod2usage(-verbose => 1) unless GetOptions("gi|g=s"       => \$genome_identifier,
-					   "infolder|i=s" => \$folder_in,
 					   "out|o=s"      => \$dest,
-					   "baseurl|b=s"  => \$base_URL,
-                                           "chromsize|c=s"  => \$chrom_size_file,
-                                           "bigwigs|bw=s" => \$big_wig_urls,
+					   "baseurl|u=s"  => \$base_URL,
+                                           "bigbeds|b=s" => \$big_bed_urls,
+                                           "bigwigs|w=s" => \$big_wig_urls,
 					   "man"          => sub{pod2usage(-verbose => 2)},
 					   "help|h"       => sub{pod2usage(1)}
 					  );
@@ -67,10 +66,6 @@ unless ($genome_identifier){
   warn "Please provide genome identifier via --g option";
   pod2usage(-verbose => 0);
 }
-unless (-d $folder_in){
-  warn "An input folder path is required and must be gi ven via --infolder option";
-  pod2usage(-verbose => 0);
-}
 unless ($base_URL =~ /^http/) {
   warn "Base URL must be given in full format, eg http://foo.bar.com/Hubs/";
   pod2usage(-verbose => 0);
@@ -81,8 +76,7 @@ unless (-d $dest){
 }
 $lf = file($dest,$logname);
 
-$track_hub_return_value = make_track_hub($genome_identifier,$folder_in,$dest,$base_URL,$chrom_size_file,$big_wig_urls,$lf);
-
+$track_hub_return_value = make_track_hub($genome_identifier,$dest,$base_URL,$big_bed_urls,$big_wig_urls,$lf);
 
 __END__
 
@@ -123,13 +117,18 @@ bigFile version.
 
 Destination folder for the output Track Hub.
 
-=item  B<--baseurl -b>
+=item  B<--baseurl -u>
 
 BaseURL used within the Track Hub. This URL will be included verbatim
 in the resulting Track Hub. It is crucial that this URl is valid, else
 the resulting Track Hub will be broken.
 
-=item  B<--bigwigs -bw>
+=item  B<--bigbeds -b>
+
+URLs pointing to big bed files to be included in the trackhub. Multiple URLs are
+separated by the character #. 
+
+=item  B<--bigwigs -w>
 
 URLs pointing to big wig files to be included in the trackhub. Multiple URLs are
 separated by the star character #. It is possible to create a multiwig container by
